format_pair: Format Cryptocurrency and Currency Pair

Description Usage Arguments Examples

View source: R/CryptoData.R

Description

Formats cryptocurrency and local currency pair to load into the "get_coin_data" package. An example of the output will resemble "BTC-USD".

Usage

1
format_pair(coin_abbreviation, currency_abbreviation)

Arguments

coin_abbreviation

Abbreviation of cryptocurrency to import (ex. "btc").

currency_abbreviation

Abbreviation of local currency (ex. "usd").

Examples

1
2
## Enter coin abbreviation and local currency abbreviation in quotes, seperated by a comma.
# format_pair("btc", "usd")

koeneralex/cryptoData documentation built on Dec. 21, 2021, 7:42 a.m.