high_52_week: 52-Week Highest Price

Description Usage Arguments Examples

View source: R/CryptoData.R

Description

Gets the highest price within a 52 week period and prints the price and date of that occurrence.

Usage

1
high_52_week(coin_data)

Arguments

coin_data

Dataframe produced by the "get_coin_data" function.

Examples

1
2
3
## Using the get_coin_data() function to obtain dataframe and inserting that dataframe in the function.
# coin_data <- get_coin_data(pair)
# high_52_week(coin_data)

koeneralex/cryptoData documentation built on Dec. 21, 2021, 7:42 a.m.