plot_coin_volume_data: Plot Cryptocurrency Trading Volume Data

Description Usage Arguments Examples

View source: R/CryptoData.R

Description

Plots cryptocurrency trading volume data using dataframe obtained through "get_coin_data" function using ggplot2.

Usage

1

Arguments

coin_data

Dataframe produced by the "get_coin_data" function.

Examples

1
2
3
## Using the get_coin_data() function to obtain dataframe and inserting that dataframe in the function.
# coin_data <- get_coin_data(pair)
# plot_coin_volume_data(coin_data)

koeneralex/cryptoData documentation built on Dec. 21, 2021, 7:42 a.m.