Description Usage Arguments Examples
Formats cryptocurrency and local currency pair to load into the "get_coin_data" package. An example of the output will resemble "BTC-USD".
1 | format_pair(coin_abbreviation, currency_abbreviation)
|
coin_abbreviation |
Abbreviation of cryptocurrency to import (ex. "btc"). |
currency_abbreviation |
Abbreviation of local currency (ex. "usd"). |
1 2 | ## Enter coin abbreviation and local currency abbreviation in quotes, seperated by a comma.
# format_pair("btc", "usd")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.