Description Usage Arguments Examples
Gets the highest price within a 52 week period and prints the price and date of that occurrence.
1 | high_52_week(coin_data)
|
coin_data |
Dataframe produced by the "get_coin_data" function. |
1 2 3 | ## Using the get_coin_data() function to obtain dataframe and inserting that dataframe in the function.
# coin_data <- get_coin_data(pair)
# high_52_week(coin_data)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.